AlfredItems class final

Constructors

AlfredItems(List<AlfredItem> items, {bool? exactOrder, bool? skipKnowledge, AlfredAutomaticCache? cache})
const
AlfredItems.fromJson(Map<String, dynamic> json)
factory

Properties

cache AlfredAutomaticCache?
Scripts which take a while to return can cache results so users see data sooner on subsequent runs. The Script Filter presents the results from the previous run when caching is active and hasn't expired. Because the script won't execute when loading cached data, we recommend this option only be used with "Alfred filters results".
final
exactOrder bool?
Alfred learns to prioritise item results like he learns any other, meaning the order in which your workflow results are presented will be based on Alfred's knowledge (using the item UID) and not the order your script returns the items.
final
first AlfredItem
getter/setter pairinherited
hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
no setterinherited
isNotEmpty bool
no setterinherited
items List<AlfredItem>
A list of zero or more AlfredItems.
final
iterator Iterator<AlfredItem>
no setterinherited
last AlfredItem
getter/setter pairinherited
length int
getter/setter pairinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
reversed Iterable<AlfredItem>
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
single AlfredItem
no setterinherited
skipKnowledge bool?
This preserves the given item order while allowing Alfred to retain knowledge of your items, like your current selection during a re-run.
final
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited

Methods

add(AlfredItem value) → void
inherited
addAll(Iterable<AlfredItem> iterable) → void
inherited
any(bool test(AlfredItem)) bool
inherited
asMap() Map<int, AlfredItem>
inherited
cast<T>() List<T>
inherited
clear() → void
inherited
contains(Object? element) bool
inherited
copyWith({List<AlfredItem>? items, bool? exactOrder, bool? skipKnowledge, AlfredAutomaticCache? cache}) AlfredItems
Copy this AlfredItems with the given items, exactOrder, skipKnowledge, of cache.
elementAt(int index) AlfredItem
inherited
every(bool test(AlfredItem)) bool
inherited
expand<T>(Iterable<T> f(AlfredItem)) Iterable<T>
inherited
fillRange(int start, int end, [AlfredItem? fillValue]) → void
inherited
firstWhere(bool test(AlfredItem), {AlfredItem orElse()?}) AlfredItem
inherited
fold<T>(T initialValue, T combine(T previousValue, AlfredItem element)) → T
inherited
followedBy(Iterable<AlfredItem> other) Iterable<AlfredItem>
inherited
forEach(void f(AlfredItem value)) → void
inherited
getRange(int start, int end) Iterable<AlfredItem>
inherited
indexOf(AlfredItem element, [int start = 0]) int
inherited
indexWhere(bool test(AlfredItem), [int start = 0]) int
inherited
insert(int index, AlfredItem element) → void
inherited
insertAll(int index, Iterable<AlfredItem> iterable) → void
inherited
join([String separator = '']) String
inherited
lastIndexOf(AlfredItem element, [int? start]) int
inherited
lastIndexWhere(bool test(AlfredItem), [int? start]) int
inherited
lastWhere(bool test(AlfredItem), {AlfredItem orElse()?}) AlfredItem
inherited
map<T>(T f(AlfredItem)) Iterable<T>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reduce(AlfredItem combine(AlfredItem value, AlfredItem element)) AlfredItem
inherited
remove(Object? value) bool
inherited
removeAt(int index) AlfredItem
inherited
removeLast() AlfredItem
inherited
removeRange(int start, int end) → void
inherited
removeWhere(bool test(AlfredItem)) → void
inherited
replaceRange(int start, int end, Iterable<AlfredItem> iterable) → void
inherited
retainWhere(bool test(AlfredItem)) → void
inherited
setAll(int index, Iterable<AlfredItem> iterable) → void
inherited
setRange(int start, int end, Iterable<AlfredItem> iterable, [int skipCount = 0]) → void
inherited
shuffle([Random? random]) → void
inherited
singleWhere(bool test(AlfredItem), {AlfredItem orElse()?}) AlfredItem
inherited
skip(int n) Iterable<AlfredItem>
inherited
skipWhile(bool test(AlfredItem)) Iterable<AlfredItem>
inherited
sort([int compare(AlfredItem, AlfredItem)?]) → void
inherited
sublist(int start, [int? end]) List<AlfredItem>
inherited
take(int n) Iterable<AlfredItem>
inherited
takeWhile(bool test(AlfredItem)) Iterable<AlfredItem>
inherited
toJson() Map<String, dynamic>
toList({bool growable = true}) List<AlfredItem>
inherited
toSet() Set<AlfredItem>
inherited
toString() String
A string representation of this object.
inherited
where(bool test(AlfredItem)) Iterable<AlfredItem>
inherited
whereType<T>() Iterable<T>
inherited

Operators

operator +(List<AlfredItem> other) List<AlfredItem>
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator [](int index) AlfredItem
inherited
operator []=(int index, AlfredItem value) → void
inherited