AlfredUserConfiguration<T, Q extends AlfredUserConfigurationConfig<T>> class abstract

Alfred user configuration generic class

Implementers

Constructors

AlfredUserConfiguration({required AlfredUserConfigurationType type, required String variable, String? description, String? label})
const

Properties

config → Q
AlfredUserConfigurationConfig configuration
final
defaultValue → T
Default value
no setter
description String?
Description
final
hashCode int
The hash code for this object.
no setterinherited
label String?
Label
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type AlfredUserConfigurationType
Type of configuration
final
value → T
User set value
no setter
variable String
Variable name
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited