AlfredUserConfigurationConfigFilePicker class final

Alfred file picker user configuration config

Inheritance
Available extensions
Annotations
  • @CopyWith.new(constructor: '_copyWith')
  • @JsonSerializable.new(explicitToJson: true, createToJson: false)

Constructors

AlfredUserConfigurationConfigFilePicker({required String defaultValue, required bool required, required int filterMode, String? value, String? placeholder})
const
AlfredUserConfigurationConfigFilePicker.fromJson(Map json)
factory

Properties

copyWith → _$AlfredUserConfigurationConfigFilePickerCWProxy

Available on AlfredUserConfigurationConfigFilePicker, provided by the $AlfredUserConfigurationConfigFilePickerCopyWith extension

Returns a callable class used to build a new instance with modified fields. Example: instanceOfAlfredUserConfigurationConfigFilePicker.copyWith(...) or instanceOfAlfredUserConfigurationConfigFilePicker.copyWith.fieldName(...).
no setter
defaultValue String
Default value
finalinherited
filterMode int
The filter mode
final
hashCode int
The hash code for this object.
no setterinherited
placeholder String?
The placeholder text to display
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
required bool
Whether the file picker is required
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
value String
User set value
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited