AlfredUserConfigurationConfigSelect class final

Alfred user configuration select class

Inheritance
Available extensions
Annotations
  • @CopyWith.new(constructor: '_copyWith')
  • @JsonSerializable.new(explicitToJson: true, createToJson: false)

Properties

copyWith → _$AlfredUserConfigurationConfigSelectCWProxy

Available on AlfredUserConfigurationConfigSelect, provided by the $AlfredUserConfigurationConfigSelectCopyWith extension

Returns a callable class used to build a new instance with modified fields. Example: instanceOfAlfredUserConfigurationConfigSelect.copyWith(...) or instanceOfAlfredUserConfigurationConfigSelect.copyWith.fieldName(...).
no setter
defaultValue String
Default value
finalinherited
hashCode int
The hash code for this object.
no setterinherited
pairs List<AlfredUserConfigurationConfigSelectPair>
The pairs of labels and values
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
value String
User set value
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited