AlfredUserConfigurationConfigTextArea class final
A configuration for a text area
- Inheritance
-
- Object
- AlfredUserConfigurationConfig<
String> - AlfredUserConfigurationConfigTextArea
- Available extensions
- Annotations
-
- @CopyWith.new(constructor: '_copyWith')
- @JsonSerializable.new(explicitToJson: true, createToJson: false)
Constructors
- AlfredUserConfigurationConfigTextArea({required String defaultValue, required bool required, required bool trim, required int verticalSize, String? value})
-
const
- AlfredUserConfigurationConfigTextArea.fromJson(Map json)
-
factory
Properties
- copyWith → _$AlfredUserConfigurationConfigTextAreaCWProxy
-
Available on AlfredUserConfigurationConfigTextArea, provided by the $AlfredUserConfigurationConfigTextAreaCopyWith extension
Returns a callable class used to build a new instance with modified fields. Example:instanceOfAlfredUserConfigurationConfigTextArea.copyWith(...)orinstanceOfAlfredUserConfigurationConfigTextArea.copyWith.fieldName(...).no setter - defaultValue → String
-
Default value
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
- required → bool
-
Whether the text area is required
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - trim → bool
-
Whether to trim the text
final
- value → String
-
User set value
finalinherited
- verticalSize → int
-
The vertical size of the text area
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited