AlfredUserConfigurationTextArea class final

Alfred text area user configuration

Inheritance
Available extensions
Annotations
  • @CopyWith.new()
  • @JsonSerializable.new(explicitToJson: true, createToJson: false)

Constructors

AlfredUserConfigurationTextArea({required AlfredUserConfigurationType type, required String variable, required AlfredUserConfigurationConfigTextArea config, String? description, String? label})
const
AlfredUserConfigurationTextArea.fromJson(Map json)
factory

Properties

config AlfredUserConfigurationConfigTextArea
The configuration for the text area
final
copyWith → _$AlfredUserConfigurationTextAreaCWProxy

Available on AlfredUserConfigurationTextArea, provided by the $AlfredUserConfigurationTextAreaCopyWith extension

Returns a callable class used to build a new instance with modified fields. Example: instanceOfAlfredUserConfigurationTextArea.copyWith(...) or instanceOfAlfredUserConfigurationTextArea.copyWith.fieldName(...).
no setter
defaultValue String
Default value
no setterinherited
description String?
Description
finalinherited
hashCode int
The hash code for this object.
no setterinherited
label String?
Label
finalinherited
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
type AlfredUserConfigurationType
Type of configuration
finalinherited
value String
User set value
no setterinherited
variable String
Variable name
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited