UserDefaults extension

on

Methods

getDefaults([String path = 'info.plist']) Future<Map<String, AlfredUserConfiguration<dynamic, AlfredUserConfigurationConfig>>?>

Available on AlfredWorkflow, provided by the UserDefaults extension

Returns a Map of user defaults from the workflow's info.plist file.
getDefaultsSync([String path = 'info.plist']) Map<String, AlfredUserConfiguration<dynamic, AlfredUserConfigurationConfig>>?

Available on AlfredWorkflow, provided by the UserDefaults extension

Synchronously returns a Map of user defaults from the workflow's info.plist file.
getUserDefaults({String prefsPath = 'prefs.plist', String infoPath = 'info.plist'}) Future<Map<String, AlfredUserConfiguration<dynamic, AlfredUserConfigurationConfig>>?>

Available on AlfredWorkflow, provided by the UserDefaults extension

Returns a Map of the user defaults from the workflow's info.plist merged with prefs.plist file.
getUserDefaultsSync({String prefsPath = 'prefs.plist', String infoPath = 'info.plist'}) Map<String, AlfredUserConfiguration<dynamic, AlfredUserConfigurationConfig>>?

Available on AlfredWorkflow, provided by the UserDefaults extension

Synchronously returns a Map of user defaults from the workflow's info.plist merged with prefs.plist file.
getUserPreferences([String path = 'prefs.plist']) Future<Map<String, dynamic>?>

Available on AlfredWorkflow, provided by the UserDefaults extension

Returns a Map of user defaults from the workflow's prefs.plist file.
getUserPreferencesSync([String path = 'prefs.plist']) Map<String, dynamic>?

Available on AlfredWorkflow, provided by the UserDefaults extension

Synchronously returns a Map of user defaults from the workflow's prefs.plist file.