AlfredAutomaticCache class
- Annotations
-
- @CopyWith.new()
- @JsonSerializable.new(createFactory: false, includeIfNull: false, ignoreUnannotated: true)
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
looseReload
→ bool?
-
The optional loosereload key asks the Script Filter to try to show any cached data first.
If it's determined to be stale, the script runs in the background and replaces results
with the new data when it becomes available.
final
-
props
→ List<Object?>
-
The list of properties that will be used to determine whether
two instances are equal.
no setter
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
seconds
→ int
-
Time to live for cached data is defined as a number of seconds between 5 and 86400 (i.e. 24 hours).
final
-
stringify
→ bool?
-
If set to
true, the toString method will be overridden to output
this instance's props.
no setterinherited
Constants
-
maxSeconds
→ const int
-
The maximum value for the cache duration.
-
minSeconds
→ const int
-
The minimum value for the cache duration.