AlfredUserConfigurationConfigTextField class final
- Inheritance
-
- Object
- AlfredUserConfigurationConfig<
String> - AlfredUserConfigurationConfigTextField
- Available extensions
- Annotations
-
- @CopyWith.new(constructor: '_copyWith')
- @JsonSerializable.new(explicitToJson: true, createToJson: false)
Constructors
- AlfredUserConfigurationConfigTextField({required String defaultValue, required bool required, required bool trim, String? value, String? placeholder})
-
const
- AlfredUserConfigurationConfigTextField.fromJson(Map json)
-
factory
Properties
- copyWith → _$AlfredUserConfigurationConfigTextFieldCWProxy
-
Available on AlfredUserConfigurationConfigTextField, provided by the $AlfredUserConfigurationConfigTextFieldCopyWith extension
Returns a callable class used to build a new instance with modified fields. Example:instanceOfAlfredUserConfigurationConfigTextField.copyWith(...)orinstanceOfAlfredUserConfigurationConfigTextField.copyWith.fieldName(...).no setter - defaultValue → String
-
Default value
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- placeholder → String?
-
Placeholder text shown in the field
final
-
props
→ List<
Object?> -
The list of properties that will be used to determine whether
two instances are equal.
no setterinherited
- required → bool
-
Whether the text field is required
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringify → bool?
-
If set to
true, thetoStringmethod will be overridden to output this instance'sprops.no setterinherited - trim → bool
-
Whether to trim leading/trailing whitespace
final
- value → String
-
User set value
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited